[PATCH libinput] evdev: Do not mark tablet touchscreens as tablets

Jason Gerecke killertofu at gmail.com
Fri Mar 27 15:34:54 PDT 2015


Devices like the Cintiq 24HDT are marked with both ID_INPUT_TABLET and
ID_INPUT_TOUCHSCREEN in udev. Be sure that we don't try to use such a
device as a tablet.

Signed-off-by: Jason Gerecke <killertofu at gmail.com>
---
For Peter's tablet-support branch.

 src/evdev.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/evdev.c b/src/evdev.c
index 19226fe..c57ac4f 100644
--- a/src/evdev.c
+++ b/src/evdev.c
@@ -1636,11 +1636,11 @@ evdev_configure_device(struct evdev_device *device)
 		}
 	}
 
-	/* libwacom assigns touchpad _and_ tablet to the tablet touch bits,
-	   so make sure we don't initialize the tablet interface for the
-	   touch device */
-	if ((udev_tags & (EVDEV_UDEV_TAG_TABLET|EVDEV_UDEV_TAG_TOUCHPAD)) ==
-	     EVDEV_UDEV_TAG_TABLET) {
+	/* libwacom assigns touchpad (or touchscreen) _and_ tablet to the
+	   tablet touch bits, so make sure we don't initialize the tablet
+	   interface for the touch device */
+	if ((udev_tags & (EVDEV_UDEV_TAG_TABLET|EVDEV_UDEV_TAG_TOUCHPAD|
+	    EVDEV_UDEV_TAG_TOUCHSCREEN)) == EVDEV_UDEV_TAG_TABLET) {
 		device->dispatch = evdev_tablet_create(device);
 		device->seat_caps |= EVDEV_DEVICE_TABLET;
 		log_info(libinput,
-- 
2.3.3



More information about the wayland-devel mailing list